use chrono::prelude::*;
use std::{fs,process};

use crate::text;

// ping a host
pub fn ping_host(address: &str, count: &u16) {
    println!("Pinging host {}, {} times.", address, count);

    // run the ping command
    let output = process::Command::new("ping")
        .arg(address)
        .arg(format!("-c {}", count))
        .output()
        .expect("Failed to execute command");

    // check that the command succeeded
    assert!(output.status.success());

    // grab the ping results from stdout
    let results_raw = &String::from_utf8_lossy(&output.stdout);
    let results = text::format::trim_output(results_raw, 4);
    for line in results {
        println!("{}", line);
    }
}

// timed file copy test to guage bandwidth speeds
pub fn bandwidth_test(download: &str, output: &str) {
    println!("Testing network bandwidth by downloading {}.", download);

    // get start time so we can track how long it takes to complete
    let start_time = Utc::now();

    // do the download

    // get finish time
    let finish_time = Utc::now();
    // compute time to complete
    let comp_time = finish_time - start_time;
    println!("{}", comp_time.num_milliseconds());

    // clean up the test file
    match fs::remove_file(output) {
        Ok(()) => println!("Cleaning up..."),
        Err(e) => println!("There was a problem during cleanup - {}", e),
    }
}
